/**
 * Copyright (c) 2013-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.launcher.exception;

/**
 * The file containing the local configuration of the container (ie, the file '
 * <code>server.properties</code>' or equivalent) is not found or access permission is denied.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class ServerPropertiesFileNotFoundException extends PetalsLauncherException {

    private static final long serialVersionUID = 369491512923506134L;

    private static final String MESSAGE_TEMPLATE = "Local configuration file not found or permission denied: '%s'.";

    /**
     * The file containing the local configuration of the container that is not
     * found or for which permissions are denied.
     */
    private final String file;

    public ServerPropertiesFileNotFoundException(final String file) {
        this(file, null);
    }

    public ServerPropertiesFileNotFoundException(final String file, final Throwable cause) {
        super(String.format(MESSAGE_TEMPLATE, file), cause);
        this.file = file;
    }

    /**
     * @return The file containing the local configuration of the container that
     *         is not found or for which permissions are denied.
     */
    public String getFile() {
        return this.file;
    }
}
